@@ -2,18 +2,17 @@ import tensorly as tl
 import torch
 from tensorly.cp_tensor import cp_to_tensor
 from tensorly.decomposition import parafac
-from torch import diag
 
 
-def mat_pow(mat, pow_, epsilon):
+def _mat_pow(mat, pow_, epsilon):
     # Computing matrix to the power of pow (pow can be negative as well)
     [D, V] = torch.linalg.eigh(mat)
-    mat_pow = V @ diag((D + epsilon).pow(pow_)) @ V.T
+    mat_pow = V @ torch.diag((D + epsilon).pow(pow_)) @ V.T
     mat_pow[mat_pow != mat_pow] = epsilon  # For stability
     return mat_pow
 
 
-def _demean(*views):
+def _demean(views):
     return tuple([view - view.mean(dim=0) for view in views])
 
 
@@ -38,9 +37,9 @@ class MCCA:
         self.r = r
         self.eps = eps
 
-    def loss(self, *views):
+    def loss(self, views):
         # Subtract the mean from each output
-        views = _demean(*views)
+        views = _demean(views)
 
         # Concatenate all views and from this get the cross-covariance matrix
         all_views = torch.cat(views, dim=1)
@@ -56,7 +55,7 @@ class MCCA:
 
         C = C - torch.block_diag(*[view.T @ view for view in views]) + D
 
-        R = mat_pow(D, -0.5, self.eps)
+        R = _mat_pow(D, -0.5, self.eps)
 
         # In MCCA our eigenvalue problem Cv = lambda Dv
         C_whitened = R @ C @ R.T
@@ -97,13 +96,13 @@ class GCCA:
         self.r = r
         self.eps = eps
 
-    def loss(self, *views):
+    def loss(self, views):
         # https: // www.uta.edu / math / _docs / preprint / 2014 / rep2014_04.pdf
         # H is n_views * n_samples * k
-        views = _demean(*views)
+        views = _demean(views)
 
         eigen_views = [
-            view @ mat_pow(view.T @ view, -1, self.eps) @ view.T for view in views
+            view @ _mat_pow(view.T @ view, -1, self.eps) @ view.T for view in views
         ]
 
         Q = torch.stack(eigen_views, dim=0).sum(dim=0)
@@ -151,24 +150,24 @@ class CCA:
         self.r = r
         self.eps = eps
 
-    def loss(self, H1, H2):
-        o1 = H1.shape[1]
-        o2 = H2.shape[1]
+    def loss(self, views):
+        o1 = views[0].shape[1]
+        o2 = views[1].shape[1]
 
-        n = H1.shape[0]
+        n = views[0].shape[0]
 
-        H1bar, H2bar = _demean(H1, H2)
+        views = _demean(views)
 
-        SigmaHat12 = (1.0 / (n - 1)) * H1bar.T @ H2bar
-        SigmaHat11 = (1 - self.r) * (
-            1.0 / (n - 1)
-        ) * H1bar.T @ H1bar + self.r * torch.eye(o1, device=H1.device)
-        SigmaHat22 = (1 - self.r) * (
-            1.0 / (n - 1)
-        ) * H2bar.T @ H2bar + self.r * torch.eye(o2, device=H2.device)
+        SigmaHat12 = (1.0 / (n - 1)) * views[0].T @ views[1]
+        SigmaHat11 = (1 - self.r) * (1.0 / (n - 1)) * views[0].T @ views[
+            0
+        ] + self.r * torch.eye(o1, device=views[0].device)
+        SigmaHat22 = (1 - self.r) * (1.0 / (n - 1)) * views[1].T @ views[
+            1
+        ] + self.r * torch.eye(o2, device=views[1].device)
 
-        SigmaHat11RootInv = mat_pow(SigmaHat11, -0.5, self.eps)
-        SigmaHat22RootInv = mat_pow(SigmaHat22, -0.5, self.eps)
+        SigmaHat11RootInv = _mat_pow(SigmaHat11, -0.5, self.eps)
+        SigmaHat22RootInv = _mat_pow(SigmaHat22, -0.5, self.eps)
 
         Tval = SigmaHat11RootInv @ SigmaHat12 @ SigmaHat22RootInv
         trace_TT = Tval.T @ Tval
@@ -200,16 +199,15 @@ class TCCA:
         self.r = r
         self.eps = eps
 
-    def loss(self, *views):
-        m = views[0].size(0)
-        views = _demean(*views)
+    def loss(self, views):
+        views = _demean(views)
         covs = [
             (1 - self.r) * view.T @ view
             + self.r * torch.eye(view.size(1), device=view.device)
             for view in views
         ]
         whitened_z = [
-            view @ mat_pow(cov, -0.5, self.eps) for view, cov in zip(views, covs)
+            view @ _mat_pow(cov, -0.5, self.eps) for view, cov in zip(views, covs)
         ]
         # The idea here is to form a matrix with M dimensions one for each view where at index
         # M[p_i,p_j,p_k...] we have the sum over n samples of the product of the pth feature of the
