@@ -11,6 +11,7 @@ def get_dataloaders(
     shuffle_train=False,
     pin_memory=True,
     num_workers=0,
+    persistent_workers=True,
 ):
     """
     A utility function to allow users to quickly get hold of the dataloaders required by pytorch lightning
@@ -24,8 +25,11 @@ def get_dataloaders(
     :param shuffle_train: whether to shuffle training data
     :param val_drop_last: whether to drop the last incomplete batch from the validation data
     :param drop_last: whether to drop the last incomplete batch from the train data
+    :param persistent_workers: whether to keep workers alive after dataloader is destroyed
 
     """
+    if num_workers == 0:
+        persistent_workers = False
     if batch_size is None:
         batch_size = len(dataset)
     train_dataloader = DataLoader(
@@ -35,6 +39,7 @@ def get_dataloaders(
         num_workers=num_workers,
         pin_memory=pin_memory,
         shuffle=shuffle_train,
+        persistent_workers=persistent_workers,
     )
     if val_dataset:
         if val_batch_size is None:
@@ -45,6 +50,7 @@ def get_dataloaders(
             drop_last=val_drop_last,
             num_workers=num_workers,
             pin_memory=pin_memory,
+            persistent_workers=persistent_workers,
         )
         return train_dataloader, val_dataloader
     return train_dataloader
