@@ -8,7 +8,7 @@ This script demonstrates how to use kernel and nonparametric methods
 # %%
 import numpy as np
 
-from cca_zoo.data import generate_covariance_data
+from cca_zoo.data import linear_simulated_data
 from cca_zoo.model_selection import GridSearchCV
 from cca_zoo.models import KCCA
 
@@ -23,7 +23,7 @@ q = 100
 latent_dims = 1
 cv = 3
 
-(X, Y), (tx, ty) = generate_covariance_data(
+(X, Y), (tx, ty) = linear_simulated_data(
     n, view_features=[p, q], latent_dims=latent_dims, correlation=[0.9]
 )
 
